/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.contribution.visualiser.google;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.SortedSet;
import java.util.TreeSet;

import org.eclipse.contribution.visualiser.core.ProviderManager;
import org.eclipse.contribution.visualiser.core.Stripe;
import org.eclipse.contribution.visualiser.interfaces.IGroup;
import org.eclipse.contribution.visualiser.interfaces.IMarkupKind;
import org.eclipse.contribution.visualiser.interfaces.IMember;
import org.eclipse.contribution.visualiser.simpleImpl.SimpleMarkupProvider;
import org.eclipse.contribution.visualiser.simpleImpl.SimpleMember;

/**
 * The markup provider for the Visualiser provider for Google search results.
 */
public class GoogleMarkupProvider extends SimpleMarkupProvider {

	public static Map markups = new HashMap();

	public static Map kindMap = new HashMap();

	public static void addResult(SearchResult result, SimpleMember mem) {
		String[] kw = result.getKeywords();
		for (int j = 0; j < kw.length; j++) {
			List m = result.getMatches(kw[j]);
			List l = (List) markups.get(mem);
			if (l == null) {
				l = new ArrayList();
				markups.put(mem, l);
			}
			GoogleMarkupKind k = (GoogleMarkupKind) kindMap.get(kw[j]);
			if (k == null) {
				k = new GoogleMarkupKind(kw[j]);
				kindMap.put(kw[j], k);
			}
			for (Iterator iter = m.iterator(); iter.hasNext();) {
				Integer offset = (Integer) iter.next();
				Stripe s = new Stripe(k, offset.intValue());
				l.add(s);
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.contribution.visualiser.interfaces.IMarkupProvider#getMemberMarkups(org.eclipse.contribution.visualiser.interfaces.IMember)
	 */
	public List getMemberMarkups(IMember member) {
		return (List) markups.get(member);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.contribution.visualiser.interfaces.IMarkupProvider#getGroupMarkups(org.eclipse.contribution.visualiser.interfaces.IGroup)
	 */
	public List getGroupMarkups(IGroup group) {
		return null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.contribution.visualiser.interfaces.IMarkupProvider#getAllMarkupKinds()
	 */
	public SortedSet getAllMarkupKinds() {
		return new TreeSet(kindMap.values());
	}

	public static void resetMarkups() {
		kindMap = new HashMap();
		markups = new HashMap();
		if (ProviderManager.getMarkupProvider() instanceof GoogleMarkupProvider) {
			((GoogleMarkupProvider) ProviderManager.getMarkupProvider())
					.resetColours();
		}
	}

}