/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.contribution.visualiser.google;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.runtime.IProgressMonitor;

import com.google.soap.search.GoogleSearch;
import com.google.soap.search.GoogleSearchFault;
import com.google.soap.search.GoogleSearchResult;
import com.google.soap.search.GoogleSearchResultElement;

/**
 * Retrieves the results of a query from the search engine. Requires the
 * googleapi.jar file from http://www.google.com/apis/download.html
 */
public class QueryEngine {

	private String clientKey = ""; // Enter your key here

	public void setKey(String key) {
		clientKey = key;
	}

	public List doQuery(String query, IProgressMonitor monitor)
			throws SearchException {

		GoogleSearch s = new GoogleSearch();
		s.setKey(clientKey);

		String[] keywords = query.split(" ");

		List results = new ArrayList();

		try {
			if (monitor != null) {
				monitor.beginTask("Performing google query", 10);
			}
			s.setQueryString(query);
			s.setSafeSearch(true);
			GoogleSearchResult r = s.doSearch();
			GoogleSearchResultElement[] re = r.getResultElements();

			for (int i = 0; i < re.length; i++) {
				String cacheURL = re[i].getURL();
				try {
					SearchResult sr = cacheQuery(cacheURL, keywords);
					sr.setName(removeTags(re[i].getTitle()));
					results.add(sr);
				} catch (IOException ioe) {
					ioe.printStackTrace();
				}
				if (monitor != null) {
					monitor.worked(1);
				}
			}
		} catch (GoogleSearchFault e) {
			throw new SearchException(e);
		}

		return results;
	}

	private static String removeTags(String str) {
		return str.replaceAll("<[^>]*>", "");
	}

	private static String removeNewlinesAndToLower(String str) {
		return str.replaceAll("\n", "").replaceAll("\r", "").toLowerCase();
	}

	private SearchResult cacheQuery(String txt, String[] keywords)
			throws IOException, GoogleSearchFault {
		SearchResult result = new SearchResult();
		result.setUrl(txt);

		GoogleSearch s = new GoogleSearch();
		s.setKey(clientKey);
		s.setSafeSearch(true);

		byte[] cachedBytes = s.doGetCachedPage(txt);
		// Note - this conversion to String should be done with reference
		// to the encoding of the cached page, but we don't do that here.
		String cachedString = removeNewlinesAndToLower(removeTags(new String(
				cachedBytes)));

		for (int i = 0; i < keywords.length; i++) {
			String kw = keywords[i].toLowerCase();
			int p = cachedString.indexOf(kw);
			while (p >= 0) {
				result.addMatch(keywords[i], p / 50);
				p = cachedString.indexOf(kw, p + kw.length());
			}
		}

		result.setLength(cachedString.length() / 50 + 2);

		return result;
	}
}